@@ -1,8 +1,8 @@
 from . import api
 from . import api_lambda
 from . import api_lambda_dynamodb
+from . import api_step_functions
 from . import dynamodb_table
-from . import http_api_step_functions
 from . import lambda_function
 from . import rest_api_sns
 from . import rest_api
